pub struct Transaction(/* private fields */);Available on crate feature
rdbc only.Expand description
The connection object that represents a rdbc database transaction object.
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn as_driver_tx(&self) -> &dyn DriverTx
pub fn as_driver_tx(&self) -> &dyn DriverTx
Get inner syscall::DriverConn reference.
Sourcepub async fn rollback(&self) -> Result<()>
pub async fn rollback(&self) -> Result<()>
Rollback this transaction.
see poll_rollback for details.
Sourcepub async fn prepare(&self, query: &str) -> Result<Prepare>
pub async fn prepare(&self, query: &str) -> Result<Prepare>
Create a prepared statement for execution via the connection.