pub struct UdpSocket(/* private fields */);Available on crate feature
net only.Expand description
A UDP socket.
After creating a UdpSocket by binding it to a socket address, data can be sent to and
received from any other socket address.
As stated in the User Datagram Protocol’s specification in IETF RFC 768, UDP is an unordered,
unreliable protocol. Refer to TcpListener and TcpStream for async TCP primitives.
This type is an async version of std::net::UdpSocket.
Implementations
Sourceimpl UdpSocket
impl UdpSocket
Sourcepub fn as_raw_ptr(&self) -> &dyn DriverUdpSocket
pub fn as_raw_ptr(&self) -> &dyn DriverUdpSocket
Returns inner driver-specific implementation.
Sourcepub async fn bind<L: ToSocketAddrs>(laddrs: L) -> Result<Self>
pub async fn bind<L: ToSocketAddrs>(laddrs: L) -> Result<Self>
Create new udp socket which will be bound to the specified laddrs
pub async fn bind_with<L: ToSocketAddrs>( laddrs: L, driver: &dyn Driver, ) -> Result<Self>
pub unsafe fn from_raw_fd_with(fd: RawFd, driver: &dyn Driver) -> Result<Self>
Available on Unix only.
pub unsafe fn from_raw_fd(fd: RawFd) -> Result<Self>
Available on Unix only.